#ifndef DGX_PHYSICS_2D_H
#define DGX_PHYSICS_2D_H

#include <engine/psx.h>
#include <engine/math.h>

/* 16 pixels == 1 meter */
#define METER		16
#define ROPE_NMASSES	8

struct Mass
{
	int		m;	/* mass value */
	VECTOR		pos;
	VECTOR		vel;
	VECTOR		force;

	/* debug members */
	int		is_debug;
	TILE_8		debug_pos;
	LINE_F2		debug_vel;
	LINE_F2		debug_force;
};

struct Spring
{
	struct Mass	*p_mass1;
	struct Mass	*p_mass2;

	int		k;
	int		length;
	int		friction;
};

struct Rope
{
	struct Mass	masses[ROPE_NMASSES];
	struct Spring	springs[ROPE_NMASSES-1];

	LINE_F2		prim[ROPE_NMASSES-1];

	int		mass_m;		/* mass value for all masses in the rope */
	int		spring_k;
	int		spring_length;
	int		spring_friction;

	VECTOR		gravity;
	VECTOR		origin_pos; /* position for tip of rope ( masses[0] ) */
	VECTOR		origin_vel;

	/* constants */
	int		air_friction;
	int		ground_height;

	/* 3d stuff */
	SVECTOR		rotation;
	VECTOR		translation;
};

#endif

